/*
Licensed Materials - Property of IBM
5725-C94, 5725-C95, 5725-C96
(C) Copyright IBM Corporation 2016. All Rights Reserved.
This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer
(a) for its own instruction and study, (b) in order to develop applications designed to run with an IBM product,
either for customer's own internal use or for redistribution by customer, as part of such an application, in customer's
own products.
*/

package com.ibm.bpm.integration.filenet;

public abstract class BPMEventHandlerConfiguration {

    private static final long CONFIGURATION_CACHE_EXPIRATION_TIME = Long.parseLong(System.getProperty("com.ibm.bpm.integration.filenet.configurationExpiration", "600000"));
    private static final boolean SEND_CREATED_EVENT_ON_CHECKOUT = Boolean.parseBoolean(System.getProperty("com.ibm.bpm.integration.filenet.sendCreatedEventOnCheckOut", "true"));

    /**
     * Returns the time in milliseconds that the content of the connection information document is cached.
     *
     * @return a duration in milliseconds
     */
    public static long getConfigurationCacheExpirationTime() {
		return CONFIGURATION_CACHE_EXPIRATION_TIME;
	}

    /**
     * Checks if a Document Created event should be send to BPM when a reservation object gets created on check-out.
     *
     * @return true if the event should be send to BPM; otherwise false
     */
	public static boolean isSendCreatedEventOnCheckOut() {
    	return SEND_CREATED_EVENT_ON_CHECKOUT;
    }
}