/*
Licensed Materials - Property of IBM
5725-C94, 5725-C95, 5725-C96, 5655-Y02
(C) Copyright IBM Corporation 2012, 2015. All Rights Reserved.
This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer
(a) for its own instruction and study, (b) in order to develop applications designed to run with an IBM product,
either for customer's own internal use or for redistribution by customer, as part of such an application, in customer's
own products.
*/

package com.ibm.bpm.integration.filenet;

import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;

public class ECMEvent {

    private String eventSourceId = null;
    private BPMEventType eventType = null;
    private String objectTypeId = null;
    private String objectId = null;
    private String relatedObjectTypeId = null;
    private String relatedObjectId = null;

    public ECMEvent(String eventSourceId, BPMEventType bpmEventType, String objectTypeId, String objectId, String relatedObjectTypeId, String relatedObjectId) {
        this.eventType = bpmEventType;
        try {
            this.eventSourceId = URLEncoder.encode(eventSourceId, "UTF-8");
            this.objectTypeId = URLEncoder.encode(objectTypeId, "UTF-8");
            this.objectId = URLEncoder.encode(objectId, "UTF-8");
            if(relatedObjectTypeId != null) {
            	this.relatedObjectTypeId = URLEncoder.encode(relatedObjectTypeId, "UTF-8");
            	this.relatedObjectId = URLEncoder.encode(relatedObjectId, "UTF-8");
            }
        } catch (UnsupportedEncodingException e) {
            throw new IllegalArgumentException(e);
        }
    }

    /**
     * Get the event source identifier
     *
     * @return the event source ID
     */
    public String getEventSourceId() {
        return eventSourceId;
    }

    /**
     * Get the event type
     *
     * @return the eventType
     */
    public BPMEventType getEventType() {
        return eventType;
    }

    /**
     * Get the object identifier
     *
     * @return an object identifier
     */
    public String getObjectId() {
        return objectId;
    }

    /**
     * Get the object type identifier
     *
     * @return an object type identifier
     */
    public String getObjectTypeId() {
        return objectTypeId;
    }

    /**
     * Get the object identifier or a related object
     *
     * @return an object identifier, may be null
     */
	public String getRelatedObjectId() {
		return relatedObjectId;
	}

    /**
     * Get the object type identifier of a related object
     *
     * @return an object type identifier, may be null
     */
	public String getRelatedObjectTypeId() {
		return relatedObjectTypeId;
	}
}
