/*
Licensed Materials - Property of IBM
5725-C94, 5725-C95, 5725-C96, 5655-Y02
(C) Copyright IBM Corporation 2012, 2015. All Rights Reserved.
This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer
(a) for its own instruction and study, (b) in order to develop applications designed to run with an IBM product,
either for customer's own internal use or for redistribution by customer, as part of such an application, in customer's
own products.
*/

package com.ibm.bpm.integration.filenet;

import java.io.IOException;
import java.util.logging.Level;
import java.util.logging.Logger;

import org.apache.commons.httpclient.DefaultHttpMethodRetryHandler;
import org.apache.commons.httpclient.HttpClient;
import org.apache.commons.httpclient.HttpMethod;
import org.apache.commons.httpclient.methods.PostMethod;
import org.apache.commons.httpclient.params.HttpMethodParams;

public class ECMEventPoster {

    private static final String CLASS_NAME = ECMEventPoster.class.getName();
    private static final Logger LOGGER = Logger.getLogger(CLASS_NAME);

    private final BPMClientConfig config;

    public ECMEventPoster(BPMClientConfig config) {
        final String METHOD_NAME = "<init>";
        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.entering(CLASS_NAME, METHOD_NAME, config);
        }

        this.config = config;

        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.exiting(CLASS_NAME, METHOD_NAME);
        }
    }

    /**
     * Sends an event
     *
     * @param event the event
     * @return the HTTP response status code
     * @throws IOException in case of an error
     */
    public int postEvent(ECMEvent event) throws IOException {
        final String METHOD_NAME = "postEvent";
        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.entering(CLASS_NAME, METHOD_NAME, event);
        }

        int statusCode = 500;

        HttpClient httpClient = this.config.getHttpClient();
        HttpMethod httpMethod = this.getHttpMethod(event);

        try {
            statusCode = httpClient.executeMethod(httpMethod);
        } finally {
            httpMethod.releaseConnection();
            if(statusCode == 200) {
                this.config.releaseHttpClient(httpClient);
            }
        }

        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.exiting(CLASS_NAME, METHOD_NAME, statusCode);
        }
        return statusCode;
    }

    private HttpMethod getHttpMethod(ECMEvent event) {
        HttpMethod method = new PostMethod(getPostEventURL(event));
        method.getParams().setParameter(HttpMethodParams.RETRY_HANDLER, new DefaultHttpMethodRetryHandler(0, false));
        return method;
    }

    private String getPostEventURL(ECMEvent event) {
        final String METHOD_NAME = "getPostEventURL";
        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.entering(CLASS_NAME, METHOD_NAME, event);
        }

        StringBuilder builder = new StringBuilder(1024);
        builder.append(this.config.getTargetServer().toString());
        builder.append(this.config.getContextRoot());
        builder.append("v1/event/ecm?eventSourceId=").append(event.getEventSourceId());
        builder.append("&objectTypeId=").append(event.getObjectTypeId());
        builder.append("&eventType=").append(event.getEventType());
        builder.append("&objectId=").append(event.getObjectId());
        if(event.getRelatedObjectId() != null) {
            builder.append("&relatedObjectTypeId=").append(event.getRelatedObjectTypeId());
            builder.append("&relatedObjectId=").append(event.getRelatedObjectId());
        }

        String url = builder.toString();

        if (LOGGER.isLoggable(Level.FINER)) {
            LOGGER.exiting(CLASS_NAME, METHOD_NAME, url);
        }
        return url;
    }
}